<?php
/**
 * Empt functions and definitions
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 * @package Empt_Lite
 */
 
 /*	-----------------------------------------------------------------------------------------------
	WordPress COMPATIBILITY
	This theme only works in WordPress 4.7 or later.
--------------------------------------------------------------------------------------------------- */
if ( version_compare( $GLOBALS['wp_version'], '4.7', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
	return;
}
 
/*	-----------------------------------------------------------------------------------------------
	GLOBAL CONTENT WIDTH
	Set the default content width.
--------------------------------------------------------------------------------------------------- */
$GLOBALS['content_width'] = 1100;


/*	-----------------------------------------------------------------------------------------------
	THEME SETUP
	Sets up theme defaults and registers support for various WordPress features.
--------------------------------------------------------------------------------------------------- */
if ( ! function_exists( 'empt_lite_setup' ) ) :
	function empt_lite_setup() {
	
		// Make theme available for translation. Translations can be filed in the /languages/ directory.
		load_theme_textdomain( 'empt-lite', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Let WordPress manage the document title.
		add_theme_support( 'title-tag' );

		// Add excerpt support to pages
		add_post_type_support( 'page', 'excerpt' );
		
		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for responsive embeds.
		add_theme_support( 'responsive-embeds' );		
		
		// Enable support for Post Thumbnails on posts and pages.
		add_theme_support( 'post-thumbnails' );
			set_post_thumbnail_size( 1100, 9999 );	
				
		// Classic blog thumbnails
		if( esc_attr(get_theme_mod( 'empt_lite_thumbnail_classic', false ) ) ) {
			add_image_size( 'empt-classic-thumbnail', 655, 400, true );
		}

		// Square blog thumbnails
		if( esc_attr(get_theme_mod( 'empt_lite_square_thumbnails', false ) ) ) {
			add_image_size( 'empt-square-thumbnail', 500, 550, true );
		}
		
		// Single thumbnails
		if( esc_attr(get_theme_mod( 'empt_lite_thumbnail_single_wide', false ) ) ) {
			add_image_size( 'empt-single-wide-thumbnail', 1100, 600, true );
		}		

		// Wide thumbnails
		if( esc_attr(get_theme_mod( 'empt_lite_wide_thumbnails', false ) ) ) {
			add_image_size( 'empt-wide-thumbnail',1100, 600, true );
		}
		
		// Recent Post thumbnails
		if( esc_attr(get_theme_mod( 'empt_lite_recent_post_thumbnail', false ) ) ) {
			add_image_size( 'empt-recent-thumbnail', 90, 90, true );
		}		
		
		// Related Post thumbnails
		if( esc_attr(get_theme_mod( 'empt_lite_related_post_thumbnail', false ) ) ) {
			add_image_size( 'empt-related-thumbnail', 500,350, true );
		}	

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'empt-lite' ),
			'footer' => esc_html__( 'Footer', 'empt-lite' ),
			'social' => esc_html__( 'Social', 'empt-lite' ),
		) );

		// Switch default core markup for search form, comment form, and comments to output valid HTML5.
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'empt_lite_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add support for post formats.
		add_theme_support( 'post-formats', array(
			'image',
			'video',
			'gallery',
			'audio',
		) );	
		
		// Add support for core custom logo.
		add_theme_support( 'custom-logo', array(
		'height'      => 250,
		'width'       => 250,
		'flex-width'  => true,
		'flex-height' => true,
		) );

		// Add support for full and wide align images.
		if ( false == esc_attr(get_theme_mod( 'empt_lite_block_css', false ) ) && ! is_page_template( 'templates/template-left.php' ) || ! is_page_template('templates/template-right.php') ) {
		add_theme_support( 'align-wide' );
		}
		
	}
endif;

add_action( 'after_setup_theme', 'empt_lite_setup' );

/*	-----------------------------------------------------------------------------------------------
	CONTENT WIDTH
	Set the content width in pixels, based on the theme's design and stylesheet
--------------------------------------------------------------------------------------------------- */
function empt_lite_content_width() {
	$content_width = $GLOBALS['content_width'];
	// Check if the page has a sidebar.
	if ( is_active_sidebar( 'left-sidebar'  ) || is_active_sidebar( 'right-sidebar' ) || is_active_sidebar( 'blog-sidebar' ) ) {
		$content_width = 720;
	}	
  $GLOBALS['content_width'] = apply_filters( 'empt_lite_content_width', $content_width );
}
add_action( 'template_redirect', 'empt_lite_content_width', 0 );
	

		
/*	-----------------------------------------------------------------------------------------------
	REGISTER STYLES
	Register and enqueue CSS
--------------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_register_styles' ) ) :
	function empt_lite_register_styles() {
				
		// Block styles
		if ( false == esc_attr(get_theme_mod( 'empt_lite_block_css', false ) ) ) {
			wp_enqueue_style( 'block-css', get_template_directory_uri() . '/css/block-styles.css', array(), null );
		}
		
		$theme_version = wp_get_theme()->get( 'Version' );
		$css_dependencies = array();

		// Retrieve and enqueue the URL for Google Fonts
		$google_fonts_url = empt_lite_fonts_url();

		if ( $google_fonts_url ) {
			wp_register_style( 'empt-google-fonts', $google_fonts_url, false, null, 'all' );
			$css_dependencies[] = 'empt-google-fonts';
		}		
		
		wp_enqueue_style( 'empt-style', get_template_directory_uri() . '/style.css', $css_dependencies, $theme_version );
		
	}
	
endif;
add_action( 'wp_enqueue_scripts', 'empt_lite_register_styles' );


/*	-----------------------------------------------------------------------------------------------
	REGISTER SCRIPTS
	Register and enqueue JavaScript
--------------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_register_scripts' ) ) :
	function empt_lite_register_scripts() {

		// Version
		$theme_version = wp_get_theme( 'empt-lite' )->get( 'Version' );
		
		// Built-in JS assets
		$js_dependencies = array( 'jquery' );
	
		// Filter the list of dependencies used  with JavaScript enqueues
		$js_dependencies = apply_filters( 'empt_lite_js_dependencies', $js_dependencies );
		
		// Theme scripts
		wp_enqueue_script( 'empt-lite-scripts', get_template_directory_uri() . '/js/theme-scripts.js', $js_dependencies, $theme_version, true );
		
		// Check Comments
		if ( ( ! is_admin() ) && is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}		
	}
	add_action( 'wp_enqueue_scripts', 'empt_lite_register_scripts' );
endif;

/*	-----------------------------------------------------------------------------------------------
	EDITOR STYLES FOR THE BLOCK EDITOR
	Assign theme block styles to the block editor
--------------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_block_editor_styles' ) ) :
	function empt_lite_block_editor_styles() {

		// Version
		$theme_version = wp_get_theme( 'empt-lite' )->get( 'Version' );
		
		// Built-in CSS assets
		$css_dependencies = array();

		// Retrieve and enqueue the URL for Google Fonts
		$google_fonts_url = empt_lite_fonts_url();

		if ( $google_fonts_url ) {
			wp_register_style( 'empt_lite_google_fonts', $google_fonts_url, false, 1.0, 'all' );
			$css_dependencies[] = 'empt_lite_google_fonts';
		}
		
		// Enqueue the editor styles	for this theme
			wp_enqueue_style( 'empt_lite_block_editor_styles', get_theme_file_uri( '/css/block-editor.css' ), $css_dependencies, $theme_version, 'all' );
	}
	add_action( 'enqueue_block_editor_assets', 'empt_lite_block_editor_styles', 1, 1 );
endif;


/* ---------------------------------------------------------------------------------------------
   EDITOR STYLES FOR THE CLASSIC EDITOR
   Assign theme styles to the classic editor - no block styles
   --------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_classic_editor_styles' ) ) :
	function empt_lite_classic_editor_styles() {

		$classic_editor_styles = array(
			'/css/classic-editor.css',
		);

		// Retrieve the Google Fonts URL and add it as a dependency
		$google_fonts_url = empt_lite_fonts_url();

		if ( $google_fonts_url ) {
			$classic_editor_styles[] = $google_fonts_url;
		}

		add_editor_style( $classic_editor_styles );

	}
	add_action( 'init', 'empt_lite_classic_editor_styles' );
endif;

/* ---------------------------------------------------------------------------------------------
   BLOCK EDITOR SETTINGS
   Add custom colors and font sizes to the block editor
------------------------------------------------------------------------------------------------ */
if ( false == esc_attr(get_theme_mod( 'empt_lite_block_styles', false ) ) ) {
	
	if ( ! function_exists( 'empt_lite_block_editor_settings' ) ) :
		function empt_lite_block_editor_settings() {

			// Add support for custom color scheme.
			add_theme_support( 'editor-color-palette', array(
				array(
				'name'  => __( 'orange', 'empt-lite' ),
				'slug'  => 'orange',
				'color' => '#d6ac6a',
				),
				array(
				'name'  => __( 'Brown', 'empt-lite' ),
				'slug'  => 'brown',
				'color' => '#ad7e35',
				),	
				array(
				'name'  => __( 'Black', 'empt-lite' ),
				'slug'  => 'black',
				'color' => '#000',
				),					
				array(
				'name'  => __( 'Grey', 'empt-lite' ),
				'slug'  => 'grey',
				'color' => '#9a9a9a',
				),			
				array(
				'name'  => __( 'Light Grey', 'empt-lite' ),
				'slug'  => 'light-grey',
				'color' => '#fbfbfb',
				),
				array(
				'name'  => __( 'White', 'empt-lite' ),
				'slug'  => 'white',
				'color' => '#fff',
				),
			) );

			// Gutenberg Font Sizes
			add_theme_support( 'editor-font-sizes', array(
				array(
					'name' 		=> _x( 'Small', 'Name of the small font size in Gutenberg', 'empt-lite' ),
					'shortName' => _x( 'S', 'Short name of the small font size in the Gutenberg editor.', 'empt-lite' ),
					'size' 		=> 14,
					'slug' 		=> 'small',
				),
				array(
					'name' 		=> _x( 'Regular', 'Name of the regular font size in Gutenberg', 'empt-lite' ),
					'shortName' => _x( 'R', 'Short name of the regular font size in the Gutenberg editor.', 'empt-lite' ),
					'size' 		=> 16,
					'slug' 		=> 'regular',
				),
				array(
					'name' 		=> _x( 'Medium', 'Name of the medium font size in Gutenberg', 'empt-lite' ),
					'shortName' => _x( 'M', 'Short name of the medium font size in the Gutenberg editor.', 'empt-lite' ),
					'size' 		=> 32,
					'slug' 		=> 'medium',
				),				
				array(
					'name' 		=> _x( 'Large', 'Name of the large font size in Gutenberg', 'empt-lite' ),
					'shortName' => _x( 'L', 'Short name of the large font size in the Gutenberg editor.', 'empt-lite' ),
					'size' 		=> 40,
					'slug' 		=> 'large',
				),
				array(
					'name' 		=> _x( 'Larger', 'Name of the larger font size in Gutenberg', 'empt-lite' ),
					'shortName' => _x( 'XL', 'Short name of the larger font size in the Gutenberg editor.', 'empt-lite' ),
					'size' 		=> 48,
					'slug' 		=> 'larger',
				),
			) );

		}
		add_action( 'after_setup_theme', 'empt_lite_block_editor_settings' );
	endif;
}

/* ---------------------------------------------------------------------------------------------
   REGISTER THEME WIDGETS
   --------------------------------------------------------------------------------------------- */
require( get_template_directory() . '/inc/widgets/recent-posts.php' );	
	
	
if ( ! function_exists( 'empt_lite_register_widgets' ) ) :
	function empt_lite_register_widgets() {

		register_widget( 'Empt_Lite_Recent_Posts' );

	}
	add_action( 'widgets_init', 'empt_lite_register_widgets' );
endif;	

/*	-----------------------------------------------------------------------------------------------
	FUNCTION FILES
	Additional theme functions
--------------------------------------------------------------------------------------------------- */
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/template-functions.php';
require get_template_directory() . '/inc/sidebars.php';
require get_template_directory() . '/inc/icons.php';
require get_template_directory() . '/inc/class-comment-walker.php';
require get_template_directory() . '/inc/inline-styles.php';

// Customizer
require get_template_directory() . '/inc/custom-controls/custom-control.php';
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/typography.php';	

