<?php
/**
 * Blog Settings
 *
 * @package Empt_Lite
 */

function empt_lite_customize_register_blog( $wp_customize ) {
    
    /** Blog Options */
    $wp_customize->add_section( 'empt_lite_blog_options', array(
            'title'    => esc_html__( 'Blog Options', 'empt-lite' ),
            'priority' => 22,
        )
    );
    
  // Blog Layout
    $wp_customize->add_setting( 'empt_lite_blog_layout', array(
		'default' => 'classic',
		'sanitize_callback' => 'empt_lite_sanitize_select',
    )
  );
  
  $wp_customize->add_control( new Empt_Lite_Select_Control(	$wp_customize,	'empt_lite_blog_layout', array(
		
		'label'   => esc_html__( 'Blog Layout', 'empt-lite' ),
		'section' => 'empt_lite_blog_options',
		'choices' => array(
			'classic'        => esc_html__( 'Classic Right Sidebar', 'empt-lite' ),
			'classic-left'        => esc_html__( 'Classic Left Sidebar', 'empt-lite' ),
			'gallery' => esc_html__( 'Gallery', 'empt-lite' ),
			)
		)
		)
  );	
	
	
	// Heading - blog excerpts
	$wp_customize->add_control( new Empt_Lite_Note_Control(
		$wp_customize, 'empt_lite_blog_excerpts_note', array(
			'label' => esc_html__( 'Blog Excerpts', 'empt-lite' ),
			'section' => 'empt_lite_blog_options',
			'settings' => array(),
			)
	) );
	
    /** Blog Excerpt */
    $wp_customize->add_setting( 'empt_lite_blog_content', array(
            'default'           => true,
            'sanitize_callback' => 'empt_lite_sanitize_checkbox',
        ) 
    );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( $wp_customize, 'empt_lite_blog_content',	array(
				'section'     => 'empt_lite_blog_options',
				'label'	      => esc_html__( 'Enable Blog Excerpt', 'empt-lite' ),
                'description' => esc_html__( 'Enable to show excerpt or disable to show full post content. Applies to the Wide and Classic blog styles.', 'empt-lite' ),
			)
		)
	);
    
    /** Excerpt Length */
    $wp_customize->add_setting( 'empt_lite_custom_excerpt_length', array(
            'default'           => 35,
            'sanitize_callback' => 'empt_lite_sanitize_number_absint',
        ) 
    );
    
    $wp_customize->add_control( new Empt_Lite_Slider_Control( 	$wp_customize,	'empt_lite_custom_excerpt_length', array(
				'section'	  => 'empt_lite_blog_options',
				'label'		  => esc_html__( 'Excerpt Length', 'empt-lite' ),
				'description' => esc_html__( 'Automatically generated excerpt length (in words).', 'empt-lite' ),
                'choices'	  => array(
					'min' 	=> 10,
					'max' 	=> 100,
					'step'	=> 5,
				)                 
			)
		)
	);


	// Add Partial for Blog Layout and Excerpt Length.
	$wp_customize->selective_refresh->add_partial( 'empt_lite_blog_content_partial', array(
		'selector'         => '.site-content',
		'settings'         => array(
			'empt_lite_blog_layout',
			'empt_lite_blog_content',
			'empt_lite_custom_excerpt_length',
		),
		'render_callback'  => 'empt_lite_customize_partial_blog_content',
		'fallback_refresh' => false,
	) );




	// Heading - blog show hide
	$wp_customize->add_control( new Empt_Lite_Note_Control(
		$wp_customize, 'empt_lite_blog_showhide_note', array(
			'label' => esc_html__( 'Show or Hide Settings', 'empt-lite' ),
			'section' => 'empt_lite_blog_options',
			'settings' => array(),
			)
	) );

  // Show blog heading group
  $wp_customize->add_setting( 'empt_lite_hide_blog_heading',  array(
      'default' => false,
	  'transport'         => 'postMessage',
      'sanitize_callback' => 'empt_lite_sanitize_checkbox',
    )
  );
  
  $wp_customize->add_control( new Empt_Lite_Toggle_Control( $wp_customize, 'empt_lite_hide_blog_heading', array(
		'section'     => 'empt_lite_blog_options',
		'label'	      => esc_html__( 'Hide the Blog Heading Group', 'empt-lite' ),
		'description' => esc_html__( 'Enable to hide the blog home page heading group.', 'empt-lite' ),
		) 
	)
  );
    
    /** Comments */
    $wp_customize->add_setting( 'empt_lite_hide_blog_comments_link', array(
            'default'           => false,
            'sanitize_callback' => 'empt_lite_sanitize_checkbox',
			 'transport'         => 'postMessage' 
        )
    );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( $wp_customize, 'empt_lite_hide_blog_comments_link', array(
                'section'     => 'empt_lite_blog_options',
                'label'       => esc_html__( 'Hide Comments', 'empt-lite' ),
                'description' => esc_html__( 'Enable to hide Comments.', 'empt-lite' ),
            )
        )
    );  

    /** Hide Category */
    $wp_customize->add_setting( 'ed_category', array(
            'default'           => false,
            'sanitize_callback' => 'empt_lite_sanitize_checkbox'
        ) 
    );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( $wp_customize, 'ed_category', array(
				'section'     => 'empt_lite_blog_options',
				'label'	      => esc_html__( 'Hide Category', 'empt-lite' ),
                'description' => esc_html__( 'Enable to hide category.', 'empt-lite' ),
			)
		)
	);
    
    /** Hide Author */
    $wp_customize->add_setting( 'empt_lite_hide_blog_author_name', array(
            'default'           => false,
			'transport'         => 'postMessage',
            'sanitize_callback' => 'empt_lite_sanitize_checkbox'
        ) 
    );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( $wp_customize, 'empt_lite_hide_blog_author_name', array(
				'section'     => 'empt_lite_blog_options',
				'label'	      => esc_html__( 'Hide Author', 'empt-lite' ),
                'description' => esc_html__( 'Enable to hide author section.', 'empt-lite' ),
			)
		)
	);
 
    /** Hide Posted Date */
    $wp_customize->add_setting( 'empt_lite_hide_blog_date',  array(
            'default'           => false,
            'sanitize_callback' => 'empt_lite_sanitize_checkbox',
			'transport'         => 'postMessage',
        ) 
    );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( $wp_customize, 'empt_lite_hide_blog_date', array(
				'section'     => 'empt_lite_blog_options',
				'label'	      => esc_html__( 'Hide Posted Date', 'empt-lite' ),
                'description' => esc_html__( 'Enable to hide posted date.', 'empt-lite' ),
			)
		)
	);
	
    /** Prefix Archive Page */
    $wp_customize->add_setting( 'empt_lite_prefix_archive', array(
            'default'           => false,
            'sanitize_callback' => 'empt_lite_sanitize_checkbox'
        ) 
    );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( $wp_customize, 'empt_lite_prefix_archive', array(
				'section'     => 'empt_lite_blog_options',
				'label'	      => esc_html__( 'Hide Prefix in Archive Page', 'empt-lite' ),
                'description' => esc_html__( 'Enable to hide prefix in archive page.', 'empt-lite' ),
			)
		)
	);

}
add_action( 'customize_register', 'empt_lite_customize_register_blog' );



/**
 * Render the blog content for the selective refresh partial.
 */
function empt_lite_customize_partial_blog_content() {
	while ( have_posts() ) {
		the_post();
		get_template_part( 'template-parts/content', get_post_format() );
	}
}
