<?php
/**
 * Blog Settings
 *
 * @package Empt_Lite
 */

function empt_lite_customize_register_post( $wp_customize ) {
    
    /** Post Options */
    $wp_customize->add_section( 'empt_lite_post_options', array(
            'title'    => esc_html__( 'Post Options', 'empt-lite' ),
            'priority' => 23,
        )
    );
    
  // Post Layout
    $wp_customize->add_setting( 'empt_lite_single_layout', array(
		'default' => 'right',
		'sanitize_callback' => 'empt_lite_sanitize_select',
    )
  );
  
  $wp_customize->add_control( new Empt_Lite_Select_Control(	$wp_customize,	'empt_lite_single_layout', array(
		'label'   => esc_html__( 'Post Layout', 'empt-lite' ),
		'section' => 'empt_lite_post_options',
		'choices' => array(
			'right' => esc_html__( 'Post with Right Sidebar', 'empt-lite' ),
			'left' => esc_html__( 'Post with Left Sidebar', 'empt-lite' ),						
			'top' => esc_html__( 'Wide Featured Image w/Title Above', 'empt-lite' ),
			)
		)
	)
  );	

	// Add Partial for single Layout
	$wp_customize->selective_refresh->add_partial( 'empt_lite_customize_partial_single_post', array(
		'selector'         => '.site-content',
		'settings'         => array(
			'empt_lite_single_layout',
			),
		'render_callback'  => 'empt_lite_customize_partial_single_content',
		'fallback_refresh' => false,
	) );


	// Heading - Post show hide
	$wp_customize->add_control( new Empt_Lite_Note_Control(
		$wp_customize, 'empt_lite_post_showhide_note', array(
			'label' => esc_html__( 'Show or Hide Settings', 'empt-lite' ),
			'section' => 'empt_lite_post_options',
			'settings' => array(),
	) ) );

	// Hide post featured image
	$wp_customize->add_setting( 'empt_lite_show_hide_post_image', array(
		'default'           => false,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'empt_lite_sanitize_checkbox',
	) );

	$wp_customize->add_control( new Empt_Lite_Toggle_Control( 
		$wp_customize, 'empt_lite_show_hide_post_image', array(
		'label'    => esc_html__( 'Hide Featured Image', 'empt-lite' ),
		'description' => esc_html__( 'Show or hide the full post featured image.', 'empt-lite' ),
		'section'  => 'empt_lite_post_options',
	) ) );

  // Hide post author
	$wp_customize->add_setting( 'empt_lite_show_post_author', array(
		'default' => false,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'empt_lite_sanitize_checkbox',
	) );
  
	$wp_customize->add_control( new Empt_Lite_Toggle_Control( 
		$wp_customize, 'empt_lite_show_post_author', array(	
		'label'    => esc_html__( 'Hide Post Author', 'empt-lite' ),
		'description' => esc_html__( 'Show or hide the full post author.', 'empt-lite' ),
		'section'  => 'empt_lite_post_options',
	) ) );	

    // Hide Posted Date
    $wp_customize->add_setting( 'empt_lite_hide_post_date',  array(
		'default'           => false,
		'sanitize_callback' => 'empt_lite_sanitize_checkbox',
		'transport'         => 'postMessage',
	) );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( 
		$wp_customize, 'empt_lite_hide_post_date', array(
		'section'     => 'empt_lite_post_options',
		'label'	      => esc_html__( 'Hide Posted Date', 'empt-lite' ),
		'description' => esc_html__( 'Show or hide the full post published date.', 'empt-lite' ),
	) ) );

    // Hide Post Category
    $wp_customize->add_setting( 'empt_lite_hide_category', array(
		'default'           => false,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'empt_lite_sanitize_checkbox'
	) );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( 
		$wp_customize, 'empt_lite_hide_category', array(
		'section'     => 'empt_lite_post_options',
		'label'	      => esc_html__( 'Hide Category', 'empt-lite' ),
		'description' => esc_html__( 'Show or hide the full post category.', 'empt-lite' ),
	) ) );

    // Hide Post Tags
    $wp_customize->add_setting( 'empt_lite_hide_post_tags', array(
		'default'           => false,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'empt_lite_sanitize_checkbox'
	) );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( 
		$wp_customize, 'empt_lite_hide_post_tags', array(
		'section'     => 'empt_lite_post_options',
		'label'	      => esc_html__( 'Hide Post Tags', 'empt-lite' ),
		'description' => esc_html__( 'Show or hide the full post list of tags.', 'empt-lite' ),
	) ) );
	
    // Hide Author Bio
    $wp_customize->add_setting( 'empt_lite_hide_author_bio', array(
		'default'           => false,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'empt_lite_sanitize_checkbox'
	) );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( 
		$wp_customize, 'empt_lite_hide_author_bio', array(
		'section'     => 'empt_lite_post_options',
		'label'	      => esc_html__( 'Hide Author Bio', 'empt-lite' ),
		'description' => esc_html__( 'Show or hide the full post author biography.', 'empt-lite' ),
	) ) );
	
    // Hide Post Navigation
    $wp_customize->add_setting( 'empt_lite_hide_post_nav', array(
		'default'           => false,
		'sanitize_callback' => 'empt_lite_sanitize_checkbox',
		 'transport'         => 'postMessage' 
	) );
    
    $wp_customize->add_control( new Empt_Lite_Toggle_Control( 
		$wp_customize, 'empt_lite_hide_post_nav', array(
		'section'     => 'empt_lite_post_options',
		'label'       => esc_html__( 'Hide Post Navigation', 'empt-lite' ),
		'description' => esc_html__( 'Show or hide the full post navigation.', 'empt-lite' ),
	) ) ); 

}
add_action( 'customize_register', 'empt_lite_customize_register_post' );



/**
 * Render single posts partial
 */
function empt_lite_customize_partial_single_post() {
	while ( have_posts() ) {
		the_post();
		get_template_part( 'template-parts/content', 'single' );
	}
}
