<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 * @package Empt_Lite
 */

/**
 * Displays the date and author of a post summary
 */
if ( ! function_exists( 'empt_lite_entry_meta' ) ) :

	function empt_lite_entry_meta() {

		echo '<ul class="post-details">' ;	

			if ( false == esc_attr(get_theme_mod( 'empt_lite_hide_blog_author_name', false ) ) ) {
				empt_lite_posted_by();
			}		
			if ( false == esc_attr(get_theme_mod( 'empt_lite_hide_blog_date', false ) ) ) {
				empt_lite_posted_on();
			}		
			if ( false == esc_attr(get_theme_mod( 'empt_lite_hide_blog_comments_link', false ) ) ) {
				empt_lite_comment_link();
			}	

		echo '</ul>';
	}
endif;

/**
 * Displays post details in short format
 */
if ( ! function_exists( 'empt_lite_short_entry_meta' ) ) :

	function empt_lite_short_entry_meta() {

		echo '<ul class="post-details">' ;	

			if ( false == esc_attr(get_theme_mod( 'empt_lite_hide_blog_author_name', false ) ) ) {
				empt_lite_posted_by();
			}		
			if ( false == esc_attr(get_theme_mod( 'empt_lite_hide_blog_date', false ) ) ) {
				empt_lite_posted_on();
			}

		echo '</ul>';
	}
endif;

/**
 * Displays post details in mini format
 */
if ( ! function_exists( 'empt_lite_mini_entry_meta' ) ) :

	function empt_lite_mini_entry_meta() {

		echo '<ul class="post-details">' ;	
		
			if ( false == esc_attr(get_theme_mod( 'empt_lite_hide_blog_date', false ) ) ) {
				empt_lite_posted_on();
			}

		echo '</ul>';
	}
endif;

/**
 * Displays the date and author of a full post
 */
if ( ! function_exists( 'empt_lite_single_entry_meta' ) ) :
	function empt_lite_single_entry_meta() {

		echo '<ul class="post-details">' ;		
			if ( false == esc_attr(get_theme_mod( 'empt_lite_show_post_author', false ) ) ) {
				empt_lite_posted_by();
			}		
			if ( false == esc_attr(get_theme_mod( 'empt_lite_hide_post_date', false ) ) ) {
				empt_lite_posted_on();
			}					
			if ( false == esc_attr(get_theme_mod( 'empt_lite_hide_category', false ) ) ) {
				empt_lite_post_categories();
				}	
			if ( false == esc_attr(get_theme_mod( 'empt_lite_hide_edit', false ) ) ) {
				empt_lite_edit_link();
			}			
		echo '</ul>';
	}
	
endif;


if ( ! function_exists( 'empt_lite_posted_on' ) ) :
	// Returns the post date
	function empt_lite_posted_on() {

		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
			);
		
		echo '<li class="publish-date"><span class="publish-date-label">' . __( 'Published', 'empt-lite' ) . '</span><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a></li>';
	}
endif;

/**
 * Prints the updated date of a post.
 */
if ( ! function_exists( 'empt_lite_updated' ) ) :
	function empt_lite_updated() {
		printf( 	
		'<li class="posted-update">' .	__( 'Updated <span>%s</span>', 'empt-lite' ) .'</li>', get_the_modified_date() );
	}
endif;

/**
 * Prints HTML with meta information about theme author.
 */
if ( ! function_exists( 'empt_lite_posted_by' ) ) :
	function empt_lite_posted_by() {
		printf(
			'<li class="byline"><span class="postauthor">%1$s </span><span class="author vcard"><a class="url fn n" href="%2$s">%3$s</a></span></li>',
			esc_html__( 'Author', 'empt-lite' ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_html( get_the_author() )
		);
	}
endif;

/**
 * Prints HTML with the comment count for the current post.
 */
if ( ! function_exists( 'empt_lite_comment_link' ) ) :
	function empt_lite_comment_link() {
		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<li class="comments-link">';
			/* translators: %s: Name of current post. Only visible to screen readers. */
			comments_popup_link( sprintf( __( 'Make a comment<span class="screen-reader-text"> on %s</span>', 'empt-lite' ), get_the_title() ) );

			echo '</li>';
		}
	}
endif;


// Show the post format label
if ( ! function_exists( 'empt_lite_post_format' ) ) :
	// Returns the post date
	function empt_lite_post_format() {
		
		$format = get_post_format();
		if ( current_theme_supports( 'post-formats', $format ) ) {		
			printf( '<li class="post-format">%1$s <a href="%2$s">%3$s</a></li>',
				esc_html__( 'type', 'empt-lite' ),
				esc_url( get_post_format_link( $format ) ),
				esc_html(get_post_format_string( $format ))				
			);
		}
	}
endif;

// Show the post edit link
if ( ! function_exists( 'empt_lite_edit_link' ) ) :
	function empt_lite_edit_link() {
		edit_post_link(
			sprintf(
				/* translators: %s: Name of current post */
				__( 'Edit Post<span class="screen-reader-text">%s</span>', 'empt-lite' ),
				get_the_title()
			),
			'<li class="edit-link">',
			'</li>'
		);
	}
endif;

// Get just the first category name of a post
if ( ! function_exists( 'empt_lite_first_category' ) ) :
	function empt_lite_first_category() {	
		$category = get_the_category();
		$first_category = $category[0];
		echo sprintf( 		
		'<li class="post-category"><span class="post-category-label">' . __( 'Category  ', 'empt-lite' ) . '</span><a href="%s">%s</a></span></li>', get_category_link( $first_category ), $first_category->name );
	}
endif;


// Get all categories of a post
if ( ! function_exists( 'empt_lite_post_categories' ) ) :
	function empt_lite_post_categories() {
			  $categories_list = get_the_category_list( esc_attr_x( ', ', 'Used between list items, there is a space after the comma.', 'empt-lite' ) );
			  if ( $categories_list ) {
				echo sprintf( '<li class="cat-links">' . __( 'in  ', 'empt-lite' ) . ' %s</li>', $categories_list );
			  }
	}
endif;

// Customize the sticky featured label
if ( ! function_exists( 'empt_lite_sticky_label' ) ) {
function empt_lite_sticky_label() {
		$empt_lite_featured_text = get_theme_mod( 'empt_lite_featured_text', __('Featured', 'empt-lite' ) );
		if ( is_sticky() && ! is_paged() &&  false == esc_attr(get_theme_mod( 'empt_lite_hide_blog_featured_label', false ) ) ) { 
    echo '<div class="featured-label">' . wp_kses_post( $empt_lite_featured_text ) . '</div>';
		}
	}
}


/**
 * Displays the post tags on single post view
 */
if ( ! function_exists( 'empt_lite_entry_tags' ) ) :
	function empt_lite_entry_tags() {	 
				$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'empt-lite' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<li class="tags-links">' . esc_html__( 'tags %1$s', 'empt-lite' ) . '</li>', $tags_list ); // WPCS: XSS OK.
			}	
	}
endif;


/**
 * Displays a standalone more link
 */
if ( ! function_exists( 'empt_lite_read_more_link' ) ) :
	function empt_lite_read_more_link() {
	$empt_lite_more_link_text = esc_html( get_theme_mod( 'empt_lite_more_link_text', __('Read More', 'empt-lite') ) );
		echo '<p><a class="more-link" href="'. esc_url(get_permalink()) . '">' . wp_kses_post( $empt_lite_more_link_text ) . '</a></p>';
	}
endif;


/* ------------------------------------------------------------------------------------------
	BLOG NAVIGATION
	Navigation for the blog home pages
--------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_blog_pagination' ) ) :
	function empt_lite_blog_pagination() {
		the_posts_pagination( array(
		'prev_text'          => esc_html__( 'Show Newer Articles', 'empt-lite' ),
		'next_text'          => esc_html__( 'Show Older Articles', 'empt-lite' ),
		'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Page', 'empt-lite' ) . ' </span>',
		) );
	}
endif;




/* ------------------------------------------------------------------------------------------
	POST NAVIGATION
	Navigation for full posts - Singles
--------------------------------------------------------------------------------------------- */
if ( ! function_exists( 'empt_lite_post_pagination' ) ) :
	function empt_lite_post_pagination() {
	
		if( get_theme_mod( 'display_post_navigation', true ) ) :
		  the_post_navigation( array(
			'next_text' => '<span class="nav-meta">' . esc_html__( 'Next post', 'empt-lite' ) . '</span> ' .
						   '<span class="post-title">%title</span>',
			'prev_text' => '<span class="nav-meta">' . esc_html__( 'Previous post', 'empt-lite' ) . '</span> ' .
			'<span class="post-title">%title</span>',
		  ) ); 
		endif;		
	}
endif;


/* ------------------------------------------------------------------------------------------
	MULTIPAGE NAVIGATION
	Navigation for splitting posts or pages into more than one page
--------------------------------------------------------------------------------------------- */
if ( ! function_exists( 'empt_lite_multipage_pagination' ) ) :
	function empt_lite_multipage_pagination() {
	
		wp_link_pages( array(
			'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'empt-lite' ) . '</span>',
			'after'       => '</div>',
			'link_before' => '<span>',
			'link_after'  => '</span>',
			'pagelink'    => ' %',
			'separator'   => ', ',
		) );
	}
endif;

  /**
   * Prints HTML with share buttons and tags after post content.
   */
if ( ! function_exists( 'empt_lite_post_tags' ) ) :

  function empt_lite_post_tags( $before = '', $after = '' ) {
    if ( ! $post = get_post() )
      return;

    $output = '';
   
      if( 'post' == $post->post_type )
        $output .= get_the_tag_list( '<div class="tags-list">', '', '</div>' );

      if( 'portfolio' == $post->post_type && taxonomy_exists( 'portfolio_tag' ) )
        $output .= get_the_term_list( $post->ID, 'portfolio_tag', '<div class="tags-list">', '', '</div>' );

    if( $output )
      printf( '%s%s%s', $before, $output, $after );
  }
endif;
